@@ -2,7 +2,7 @@ from django import forms
 from django.db.models.fields import BLANK_CHOICE_DASH
 from django.forms import formset_factory
 
-from wagtail.core.models import Page
+from wagtail.models import Page
 
 from wagtailinventory.models import PageBlock
 
@@ -18,8 +18,7 @@ class PageBlockQueryForm(forms.Form):
     )
 
     has = forms.ChoiceField(
-        choices=((c, c) for c in (INCLUDES_BLOCK, EXCLUDES_BLOCK)),
-        label=None,
+        choices=((c, c) for c in (INCLUDES_BLOCK, EXCLUDES_BLOCK)), label=None
     )
 
     def __init__(self, *args, **kwargs):
