@@ -21,7 +21,7 @@ WAGTAIL_APPS = (
     "wagtail.contrib.forms",
     "wagtail.contrib.settings",
     "wagtail.admin",
-    "wagtail.core",
+    "wagtail",
     "wagtail.documents",
     "wagtail.images",
     "wagtail.sites",
@@ -30,7 +30,7 @@ WAGTAIL_APPS = (
 
 WAGTAILADMIN_RICH_TEXT_EDITORS = {
     "default": {"WIDGET": "wagtail.admin.rich_text.DraftailRichTextArea"},
-    "custom": {"WIDGET": "wagtail.tests.testapp.rich_text.CustomRichTextArea"},
+    "custom": {"WIDGET": "wagtail.test.testapp.rich_text.CustomRichTextArea"},
 }
 
 MIDDLEWARE = (
@@ -86,3 +86,5 @@ TEMPLATES = [
 WAGTAIL_SITE_NAME = "Test Site"
 
 ROOT_URLCONF = "wagtailinventory.tests.urls"
+
+WAGTAILADMIN_BASE_URL = "http://localhost:8000"
