@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-from django.db import migrations, models
 import django.db.models.deletion
+from django.db import migrations, models
 
-from wagtail.core import blocks as core_blocks
-from wagtail.core import fields as core_fields  # pragma: no cover
+from wagtail import blocks as core_blocks
+from wagtail import fields as core_fields
 
 
 class Migration(migrations.Migration):
@@ -17,7 +17,7 @@ class Migration(migrations.Migration):
             name='NestedStreamBlockPage',
             fields=[
                 ('page_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
-                ('content', core_fields.StreamField([('streamblock', core_blocks.StreamBlock([('text', core_blocks.CharBlock()), ('atom', core_blocks.StructBlock([('title', core_blocks.CharBlock())]))]))])),
+                ('content', core_fields.StreamField([('streamblock', core_blocks.StreamBlock([('text', core_blocks.CharBlock()), ('atom', core_blocks.StructBlock([('title', core_blocks.CharBlock())]))]))], use_json_field=True)),
             ],
             options={
                 'abstract': False,
