@@ -1,14 +1,15 @@
 from django.conf import settings
 
+from wagtail import urls as wagtailcore_urls
 from wagtail.admin import urls as wagtailadmin_urls
-from wagtail.core import urls as wagtailcore_urls
 from wagtail.documents import urls as wagtaildocs_urls
 
 
 try:
     from django.urls import include, re_path
 except ImportError:
-    from django.conf.urls import include, url as re_path
+    from django.conf.urls import include
+    from django.conf.urls import url as re_path
 
 
 urlpatterns = [
