@@ -3,7 +3,7 @@ from wagtailinventory.views import SearchView
 
 try:
     from django.urls import re_path
-except ImportError:
+except ImportError:  # pragma: no cover
     from django.conf.urls import url as re_path
 
 
