@@ -1,9 +1,9 @@
+from django.core.paginator import Paginator
 from django.http import HttpResponseBadRequest
 from django.shortcuts import render
 from django.views.generic import View
 
-import wagtail
-from wagtail.core.models import Page
+from wagtail.models import Page
 
 from wagtailinventory.forms import PageBlockQueryFormSet
 
@@ -24,16 +24,8 @@ class SearchView(View):
 
         queryset = queryset.order_by("title")
 
-        # https://docs.wagtail.io/en/latest/releases/2.5.html#changes-to-admin-pagination-helpers
-        if wagtail.VERSION < (2, 5):
-            from wagtail.utils.pagination import paginate
-
-            paginator, pages = paginate(request, queryset)
-        else:  # pragma: no cover
-            from django.core.paginator import Paginator
-
-            paginator = Paginator(queryset, per_page=20)
-            pages = paginator.get_page(request.GET.get("p"))
+        paginator = Paginator(queryset, per_page=20)
+        pages = paginator.get_page(request.GET.get("p"))
 
         for page in pages:
             page.can_choose = True
